summaryrefslogtreecommitdiff
path: root/basegfx/inc
diff options
context:
space:
mode:
authorVladimir Glazounov <vg@openoffice.org>2008-08-19 22:52:14 +0000
committerVladimir Glazounov <vg@openoffice.org>2008-08-19 22:52:14 +0000
commit4a287eadb849020f5df8e1920cb1f3885cebb732 (patch)
tree473d1c84cd5220ae542e529661771861bf5902c8 /basegfx/inc
parent3a4ee04e6c5bfa775ae6884c95c5be1619e23d4c (diff)
INTEGRATION: CWS aw033 (1.1.8); FILE MERGED
2008/05/14 14:42:26 aw 1.1.8.4: RESYNC: (1.2-1.3); FILE MERGED 2007/12/03 13:53:13 aw 1.1.8.3: #i39532# checkin for resync 2006/05/16 14:09:24 aw 1.1.8.2: handish adaptions after resync 2005/10/28 11:21:19 aw 1.1.8.1: #i39532#
Diffstat (limited to 'basegfx/inc')
-rw-r--r--basegfx/inc/basegfx/polygon/b2dpolygonclipper.hxx23
1 files changed, 8 insertions, 15 deletions
diff --git a/basegfx/inc/basegfx/polygon/b2dpolygonclipper.hxx b/basegfx/inc/basegfx/polygon/b2dpolygonclipper.hxx
index f348030123f2..d604c454a81f 100644
--- a/basegfx/inc/basegfx/polygon/b2dpolygonclipper.hxx
+++ b/basegfx/inc/basegfx/polygon/b2dpolygonclipper.hxx
@@ -7,7 +7,7 @@
* OpenOffice.org - a multi-platform office productivity suite
*
* $RCSfile: b2dpolygonclipper.hxx,v $
- * $Revision: 1.3 $
+ * $Revision: 1.4 $
*
* This file is part of OpenOffice.org.
*
@@ -50,36 +50,29 @@ namespace basegfx
// The value bAboveAxis defines on which side the return value will be (true -> above X, right of Y).
// The switch bStroke decides if the polygon is interpreted as area (false) or strokes (true).
B2DPolyPolygon clipPolyPolygonOnParallelAxis(const B2DPolyPolygon& rCandidate, bool bParallelToXAxis, bool bAboveAxis, double fValueOnOtherAxis, bool bStroke);
-
- // version for Polygons
B2DPolyPolygon clipPolygonOnParallelAxis(const B2DPolygon& rCandidate, bool bParallelToXAxis, bool bAboveAxis, double fValueOnOtherAxis, bool bStroke);
// Clip the given PolyPolygon against the given range. bInside defines if the result will contain the
// parts which are contained in the range or vice versa.
// The switch bStroke decides if the polygon is interpreted as area (false) or strokes (true).
B2DPolyPolygon clipPolyPolygonOnRange(const B2DPolyPolygon& rCandidate, const B2DRange& rRange, bool bInside, bool bStroke);
-
- // version for Polygons
B2DPolyPolygon clipPolygonOnRange(const B2DPolygon& rCandidate, const B2DRange& rRange, bool bInside, bool bStroke);
- // Clip given PolyPolygon against the endless edge defined by the given two points. bAbove defines on which side
+ // Clip given PolyPolygon against the endless edge (ray) defined by the given two points. bAbove defines on which side
// of the edge the result will be together with the definition of the edge. If the edge is seen as a vector
// from A to B and bAbove is true, the result will contain the geometry left of the vector.
// The switch bStroke decides if the polygon is interpreted as area (false) or strokes (true).
B2DPolyPolygon clipPolyPolygonOnEdge(const B2DPolyPolygon& rCandidate, const B2DPoint& rPointA, const B2DPoint& rPointB, bool bAbove, bool bStroke);
-
- // version for Polygons
B2DPolyPolygon clipPolygonOnEdge(const B2DPolygon& rCandidate, const B2DPoint& rPointA, const B2DPoint& rPointB, bool bAbove, bool bStroke);
// Clip given PolyPolygon against given clipping polygon.
// The switch bStroke decides if the polygon is interpreted as area (false) or strokes (true).
- // With stroke polygons, You get all ine snippets inside rCip. For convenience, You may use bInvert to get everything outside rClip.
- // With filled polygons, You get all PolyPolygon parts which were inside rClip. Those polygons are in no way reduced, so
- // it may be necessary to clean them up using their overlapping information.
- B2DPolyPolygon clipPolyPolygonOnPolyPolygon(const B2DPolyPolygon& rCandidate, const B2DPolyPolygon& rClip, bool bStroke, bool bInvert = false);
-
- // version for Polygons
- B2DPolyPolygon clipPolygonOnPolyPolygon(const B2DPolygon& rCandidate, const B2DPolyPolygon& rClip, bool bStroke, bool bInvert = false);
+ // With stroke polygons, You get all line snippets inside rCip.
+ // With filled polygons, You get all PolyPolygon parts which were inside rClip.
+ // The switch bInside decides if the parts inside the clip polygon or outside shall be created.
+ // The clip polygon is always assumed closed, even when it's isClosed() is false.
+ B2DPolyPolygon clipPolyPolygonOnPolyPolygon(const B2DPolyPolygon& rCandidate, const B2DPolyPolygon& rClip, bool bInside, bool bStroke);
+ B2DPolyPolygon clipPolygonOnPolyPolygon(const B2DPolygon& rCandidate, const B2DPolyPolygon& rClip, bool bInside, bool bStroke);
// clip the given polygon against the given range. the resulting polygon will always contain
// the inside parts which will always be interpreted as areas. the incoming polygon is expected